@@ -92,7 +92,7 @@ sub _seek {
 
 =head2 skipping_doc
 
-Does nothing.
+By default this does nothing. You may wish to override it to do something.
 
 =cut
 
@@ -143,7 +143,8 @@ sub read {
 	my (@docs, @freqs);
 	while ($self->{freq_count} > 0) {
 		$self->_read_one;
-		next if $self->{deleted_docs}
+		next
+			if $self->{deleted_docs}
 			&& $self->{deleted_docs}->get($self->{doc});
 		push @docs,  $self->doc;
 		push @freqs, $self->freq;
